diff --git a/inc/class-wooviet-admin-page.php b/inc/class-wooviet-admin-page.php
index 9fe3477..25c7b75 100644
--- a/inc/class-wooviet-admin-page.php
+++ b/inc/class-wooviet-admin-page.php
@@ -136,7 +136,7 @@ class WooViet_Admin_Page {
-
the Paypal Standard gateway', 'woocommerce-for-vietnam' ), 'https://docs.woocommerce.com/document/paypal-standard/' ) ?>
+
the PayPal Standard gateway', 'woocommerce-for-vietnam' ), 'https://docs.woocommerce.com/document/paypal-standard/' ) ?>
-
+
diff --git a/readme.txt b/readme.txt
index 9ee9d9c..862fa84 100644
--- a/readme.txt
+++ b/readme.txt
@@ -21,7 +21,7 @@ Add features to WooCommerce stores having anything related to Vietnam: currency,
* Change the VND currency symbol `đ` to anything, e.g: `VND`, `VNĐ`, `đồng`, etc.
* Add provinces for Vietnam when visitors select Vietanm as a country of the shipping (billing) address. This is not available in WooCommerce by default.
* Convert `000` of prices to K (or anything). E.g: `50000` (VND) will be `50K` (VND), or `50 thousands` (VND).
-* Support `VND` for the [PayPal Standard gateway](https://docs.woocommerce.com/document/paypal-standard/). Convert `VND` prices to any PayPal supported currency before sending visitors to the PayPal pages.
+* Support `VND` for [the PayPal Standard gateway](https://docs.woocommerce.com/document/paypal-standard/). Convert `VND` prices to any PayPal supported currency before sending visitors to the PayPal pages.
**Road Map**
diff --git a/inc/class-wooviet-vnd-paypal-standard.php b/inc/class-wooviet-vnd-paypal-standard.php
index 6fe9aca..cd8e7d0 100644
--- a/inc/class-wooviet-vnd-paypal-standard.php
+++ b/inc/class-wooviet-vnd-paypal-standard.php
@@ -4,7 +4,7 @@ if ( ! defined( 'ABSPATH' ) ) {
}
/**
* The class to add the support for VND when using the Paypal Standard gateway
*
* @see https://docs.woocommerce.com/document/paypal-standard/
*
@@ -14,7 +14,7 @@ if ( ! defined( 'ABSPATH' ) ) {
* @since 1.0
*
*/
-class WooViet_VND_Paypal_Standard {
+class WooViet_VND_PayPal_Standard {
/**
* @var int
@@ -26,7 +26,7 @@ class WooViet_VND_Paypal_Standard {
protected $paypal_currency = 'USD';
/**
- * WooViet_VND_Paypal_Standard constructor.
+ * WooViet_VND_PayPal_Standard constructor.
*
* @param int $exchange_rate_to_vnd
*/
@@ -35,13 +35,13 @@ class WooViet_VND_Paypal_Standard {
$this->exchange_rate_to_vnd = (int) $exchange_rate_to_vnd;
$this->paypal_currency = $paypal_currency;
// Add VND to the Paypal supported currencies
add_filter( 'woocommerce_paypal_supported_currencies', array( $this, 'add_vnd_paypal_valid_currency' ) );
// Covert VND prices to the selected currency (by default, it's USD) prices before checking out with Paypal Standard
add_filter( 'woocommerce_paypal_args', array( $this, 'convert_prices' ), 11 );
// Add the exchange rate info for this gateway in the checkout page before proceeding in the Paypal pages
add_filter( 'option_woocommerce_paypal_settings', array( $this, 'add_exchange_rate_info' ), 11 );
}
@@ -97,7 +97,7 @@ class WooViet_VND_Paypal_Standard {
$value['description'] .= ' ';
$value['description'] .=
- sprintf( __( 'The prices will be converted to %1$s in the Paypal pages with the exchange rate %2$s.', 'woocommerce-for-vietnam' ),
+ sprintf( __( 'The prices will be converted to %1$s in the PayPal pages with the exchange rate %2$s.', 'woocommerce-for-vietnam' ),
" $this->paypal_currency",
" $this->paypal_currency / VND = $this->exchange_rate_to_vnd"
);
@@ -4,7 +4,7 @@ if ( ! defined( 'ABSPATH' ) ) {
}
/**
- * The class to add the support for VND when using the Paypal Standard gateway
+ * The class to add the support for VND when using the PayPal Standard gateway
*
* @see https://docs.woocommerce.com/document/paypal-standard/
@@ -35,13 +35,13 @@ class WooViet_VND_Paypal_Standard {
$this->exchange_rate_to_vnd = (int) $exchange_rate_to_vnd;
$this->paypal_currency = $paypal_currency;
- // Add VND to the Paypal supported currencies
+ // Add VND to the PayPal supported currencies
add_filter( 'woocommerce_paypal_supported_currencies', array( $this, 'add_vnd_paypal_valid_currency' ) );
@@ -35,13 +35,13 @@ class WooViet_VND_Paypal_Standard {
add_filter( 'woocommerce_paypal_supported_currencies', array( $this, 'add_vnd_paypal_valid_currency' ) );
- // Covert VND prices to the selected currency (by default, it's USD) prices before checking out with Paypal Standard
+ // Covert VND prices to the selected currency (by default, it's USD) prices before checking out with PayPal Standard
add_filter( 'woocommerce_paypal_args', array( $this, 'convert_prices' ), 11 );
@@ -35,13 +35,13 @@ class WooViet_VND_Paypal_Standard {
add_filter( 'woocommerce_paypal_args', array( $this, 'convert_prices' ), 11 );
- // Add the exchange rate info for this gateway in the checkout page before proceeding in the Paypal pages
+ // Add the exchange rate info for this gateway in the checkout page before proceeding in the PayPal pages
add_filter( 'option_woocommerce_paypal_settings', array( $this, 'add_exchange_rate_info' ), 11 );
}
diff --git a/woocommerce-for-vietnam.php b/woocommerce-for-vietnam.php
index 77656df..b8dfd67 100644
--- a/woocommerce-for-vietnam.php
+++ b/woocommerce-for-vietnam.php
@@ -66,7 +66,7 @@ class WooViet {
*/
protected $Provinces;
protected $Currency;
- protected $VND_Paypal_Standard;
+ protected $VND_PayPal_Standard;
protected $Admin_Page;
/**
@@ -149,10 +149,10 @@ class WooViet {
}
// Check if "Support VND for the Paypal Standard gateway" is enabled
if ( 'yes' == $settings['vnd_paypal_standard']['enabled'] ) {
include( WOO_VIET_DIR . 'inc/class-wooviet-vnd-paypal-standard.php' );
- $this->VND_Paypal_Standard = new WooViet_VND_Paypal_Standard(
+ $this->VND_PayPal_Standard = new WooViet_VND_PayPal_Standard(
$settings['vnd_paypal_standard']['rate'],
$settings['vnd_paypal_standard']['currency']
);
@@ -149,10 +149,10 @@ class WooViet {
}
- // Check if "Support VND for the Paypal Standard gateway" is enabled
+ // Check if "Support VND for the PayPal Standard gateway" is enabled
if ( 'yes' == $settings['vnd_paypal_standard']['enabled'] ) {
include( WOO_VIET_DIR . 'inc/class-wooviet-vnd-paypal-standard.php' );